Orange3-Educational
===================

Educational widgets for machine learning and data mining in 
[Orange](http://orange.biolab.si).

**License: CC-BY-NC-3.0**

In order to use this package commercially, please obtain a [Highcharts] license.

[Highcharts]: http://www.highcharts.com/

Widgets in Educational Add-on demonstrate several key data mining and machine learning procedures.
The widgets are useful for beginners to understand the inner working of key algorithms in the data
mining and for teachers to be able to visually explain various methods in a classroom.

Installation
------------

To install the add-on with pip use

    pip install Orange3-Educational

To install the add-on from source, run

    python setup.py install

To register this add-on with Orange, but keep the code in the development directory (do not copy it to 
Python's site-packages directory), run

    python setup.py develop

Usage
-----

After the installation, the widgets from this add-on are registered with
Orange. To run Orange from the terminal,
use

    python3 -m Orange.canvas

new widgets are in the toolbox bar under Educational section.
